map = [
    {
        "to_v":35,
        "iso2_code":None,
        "from_h":0,
        "gaul_label":None,
        "gaul_code":"0",
        "iso3_code":None,
        "from_v":0,
        "to_h":35
    },
    {
        "to_v":4,
        "iso2_code":"CA",
        "from_h":9,
        "gaul_label":"Canada",
        "gaul_code":"46",
        "iso3_code":"CAN",
        "from_v":0,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"ST",
        "from_h":18,
        "gaul_label":"Sao Tome and Principe",
        "gaul_code":"214",
        "iso3_code":"STP",
        "from_v":8,
        "to_h":18
    },
    {
        "to_v":7,
        "iso2_code":"GW",
        "from_h":16,
        "gaul_label":"Guinea-Bissau",
        "gaul_code":"105",
        "iso3_code":"GNB",
        "from_v":7,
        "to_h":16
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":15,
        "gaul_label":"Azores Islands",
        "gaul_code":"74578",
        "iso3_code":"PRT",
        "from_v":5,
        "to_h":16
    },
    {
        "to_v":7,
        "iso2_code":"US",
        "from_h":2,
        "gaul_label":"United States of America",
        "gaul_code":"259",
        "iso3_code":"USA",
        "from_v":1,
        "to_h":29
    },
    {
        "to_v":10,
        "iso2_code":"TZ",
        "from_h":20,
        "gaul_label":"United Republic of Tanzania",
        "gaul_code":"257",
        "iso3_code":"TZA",
        "from_v":9,
        "to_h":21
    },
    {
        "to_v":3,
        "iso2_code":"LT",
        "from_h":19,
        "gaul_label":"Lithuania",
        "gaul_code":"147",
        "iso3_code":"LTU",
        "from_v":3,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":"KH",
        "from_h":27,
        "gaul_label":"Cambodia",
        "gaul_code":"44",
        "iso3_code":"KHM",
        "from_v":7,
        "to_h":28
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":1,
        "gaul_label":"Kingman Reef",
        "gaul_code":"134",
        "iso3_code":None,
        "from_v":8,
        "to_h":1
    },
    {
        "to_v":4,
        "iso2_code":"CH",
        "from_h":18,
        "gaul_label":"Switzerland",
        "gaul_code":"237",
        "iso3_code":"CHE",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":8,
        "iso2_code":"ET",
        "from_h":21,
        "gaul_label":"Ethiopia",
        "gaul_code":"79",
        "iso3_code":"ETH",
        "from_v":7,
        "to_h":22
    },
    {
        "to_v":7,
        "iso2_code":"AW",
        "from_h":11,
        "gaul_label":"Aruba",
        "gaul_code":"14",
        "iso3_code":"ABW",
        "from_v":7,
        "to_h":11
    },
    {
        "to_v":11,
        "iso2_code":"SZ",
        "from_h":20,
        "gaul_label":"Swaziland",
        "gaul_code":"235",
        "iso3_code":"SWZ",
        "from_v":11,
        "to_h":20
    },
    {
        "to_v":1,
        "iso2_code":"SJ",
        "from_h":17,
        "gaul_label":"Svalbard and Jan Mayen Islands",
        "gaul_code":"234",
        "iso3_code":"SJM",
        "from_v":0,
        "to_h":18
    },
    {
        "to_v":10,
        "iso2_code":"WF",
        "from_h":0,
        "gaul_label":"Wallis and Futuna",
        "gaul_code":"266",
        "iso3_code":"WLF",
        "from_v":10,
        "to_h":0
    },
    {
        "to_v":14,
        "iso2_code":"AR",
        "from_h":11,
        "gaul_label":"Argentina",
        "gaul_code":"12",
        "iso3_code":"ARG",
        "from_v":11,
        "to_h":14
    },
    {
        "to_v":11,
        "iso2_code":"BO",
        "from_h":11,
        "gaul_label":"Bolivia",
        "gaul_code":"33",
        "iso3_code":"BOL",
        "from_v":9,
        "to_h":12
    },
    {
        "to_v":8,
        "iso2_code":"CM",
        "from_h":18,
        "gaul_label":"Cameroon",
        "gaul_code":"45",
        "iso3_code":"CMR",
        "from_v":7,
        "to_h":19
    },
    {
        "to_v":8,
        "iso2_code":"BF",
        "from_h":17,
        "gaul_label":"Burkina Faso",
        "gaul_code":"42",
        "iso3_code":"BFA",
        "from_v":7,
        "to_h":18
    },
    {
        "to_v":5,
        "iso2_code":"TM",
        "from_h":21,
        "gaul_label":"Turkmenistan",
        "gaul_code":"250",
        "iso3_code":"TKM",
        "from_v":4,
        "to_h":23
    },
    {
        "to_v":6,
        "iso2_code":"BH",
        "from_h":22,
        "gaul_label":"Bahrain",
        "gaul_code":"21",
        "iso3_code":"BHR",
        "from_v":6,
        "to_h":22
    },
    {
        "to_v":3,
        "iso2_code":"GB",
        "from_h":17,
        "gaul_label":"U.K. of Great Britain and Northern Ireland",
        "gaul_code":"256",
        "iso3_code":"GBR",
        "from_v":2,
        "to_h":18
    },
    {
        "to_v":7,
        "iso2_code":"SA",
        "from_h":21,
        "gaul_label":"Saudi Arabia",
        "gaul_code":"215",
        "iso3_code":"SAU",
        "from_v":5,
        "to_h":23
    },
    {
        "to_v":9,
        "iso2_code":"RW",
        "from_h":20,
        "gaul_label":"Rwanda",
        "gaul_code":"205",
        "iso3_code":"RWA",
        "from_v":9,
        "to_h":21
    },
    {
        "to_v":13,
        "iso2_code":"SH",
        "from_h":16,
        "gaul_label":"Saint Helena",
        "gaul_code":"207",
        "iso3_code":"SHN",
        "from_v":9,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"TG",
        "from_h":18,
        "gaul_label":"Togo",
        "gaul_code":"243",
        "iso3_code":"TGO",
        "from_v":7,
        "to_h":18
    },
    {
        "to_v":6,
        "iso2_code":"JP",
        "from_h":27,
        "gaul_label":"Japan",
        "gaul_code":"126",
        "iso3_code":"JPN",
        "from_v":4,
        "to_h":31
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":20,
        "gaul_label":"Abyei",
        "gaul_code":"102",
        "iso3_code":None,
        "from_v":7,
        "to_h":20
    },
    {
        "to_v":10,
        "iso2_code":"CC",
        "from_h":27,
        "gaul_label":"Cocos (Keeling) Islands",
        "gaul_code":"56",
        "iso3_code":"CCK",
        "from_v":10,
        "to_h":27
    },
    {
        "to_v":6,
        "iso2_code":"PK",
        "from_h":23,
        "gaul_label":"Pakistan",
        "gaul_code":"188",
        "iso3_code":"PAK",
        "from_v":5,
        "to_h":24
    },
    {
        "to_v":7,
        "iso2_code":"GT",
        "from_h":9,
        "gaul_label":"Guatemala",
        "gaul_code":"103",
        "iso3_code":"GTM",
        "from_v":7,
        "to_h":9
    },
    {
        "to_v":4,
        "iso2_code":"BA",
        "from_h":19,
        "gaul_label":"Bosnia and Herzegovina",
        "gaul_code":"34",
        "iso3_code":"BIH",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":6,
        "iso2_code":"KG",
        "from_h":22,
        "gaul_label":"Kuwait",
        "gaul_code":"137",
        "iso3_code":"KWT",
        "from_v":5,
        "to_h":22
    },
    {
        "to_v":4,
        "iso2_code":"RU",
        "from_h":10,
        "gaul_label":"Russian Federation",
        "gaul_code":"204",
        "iso3_code":"RUS",
        "from_v":0,
        "to_h":28
    },
    {
        "to_v":6,
        "iso2_code":"JO",
        "from_h":20,
        "gaul_label":"Jordan",
        "gaul_code":"130",
        "iso3_code":"JOR",
        "from_v":5,
        "to_h":21
    },
    {
        "to_v":10,
        "iso2_code":None,
        "from_h":30,
        "gaul_label":"Ashmore and Cartier Islands",
        "gaul_code":"16",
        "iso3_code":None,
        "from_v":10,
        "to_h":30
    },
    {
        "to_v":7,
        "iso2_code":"DM",
        "from_h":12,
        "gaul_label":"Dominica",
        "gaul_code":"71",
        "iso3_code":"DMA",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":8,
        "iso2_code":"LR",
        "from_h":16,
        "gaul_label":"Liberia",
        "gaul_code":"144",
        "iso3_code":"LBR",
        "from_v":8,
        "to_h":17
    },
    {
        "to_v":9,
        "iso2_code":"MV",
        "from_h":25,
        "gaul_label":"Maldives",
        "gaul_code":"154",
        "iso3_code":"MDV",
        "from_v":8,
        "to_h":25
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":24,
        "gaul_label":"China/India",
        "gaul_code":"52",
        "iso3_code":None,
        "from_v":5,
        "to_h":24
    },
    {
        "to_v":7,
        "iso2_code":"JM",
        "from_h":10,
        "gaul_label":"Jamaica",
        "gaul_code":"123",
        "iso3_code":"JAM",
        "from_v":7,
        "to_h":10
    },
    {
        "to_v":7,
        "iso2_code":"OM",
        "from_h":22,
        "gaul_label":"Oman",
        "gaul_code":"187",
        "iso3_code":"OMN",
        "from_v":6,
        "to_h":23
    },
    {
        "to_v":7,
        "iso2_code":"MQ",
        "from_h":12,
        "gaul_label":"Martinique",
        "gaul_code":"158",
        "iso3_code":"MTQ",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":10,
        "iso2_code":"ZM",
        "from_h":20,
        "gaul_label":"Zambia",
        "gaul_code":"270",
        "iso3_code":"ZMB",
        "from_v":9,
        "to_h":21
    },
    {
        "to_v":7,
        "iso2_code":"VI",
        "from_h":11,
        "gaul_label":"United States Virgin Islands",
        "gaul_code":"258",
        "iso3_code":"VIR",
        "from_v":7,
        "to_h":11
    },
    {
        "to_v":10,
        "iso2_code":"CX",
        "from_h":28,
        "gaul_label":"Christmas Island",
        "gaul_code":"54",
        "iso3_code":"CXR",
        "from_v":10,
        "to_h":28
    },
    {
        "to_v":8,
        "iso2_code":"GF",
        "from_h":12,
        "gaul_label":"French Guiana",
        "gaul_code":"86",
        "iso3_code":"GUF",
        "from_v":8,
        "to_h":12
    },
    {
        "to_v":10,
        "iso2_code":"NU",
        "from_h":1,
        "gaul_label":"Niue",
        "gaul_code":"183",
        "iso3_code":"NIU",
        "from_v":10,
        "to_h":1
    },
    {
        "to_v":4,
        "iso2_code":"MC",
        "from_h":18,
        "gaul_label":"Monaco",
        "gaul_code":"166",
        "iso3_code":"MCO",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":6,
        "iso2_code":None,
        "from_h":26,
        "gaul_label":"Arunachal Pradesh",
        "gaul_code":"15",
        "iso3_code":None,
        "from_v":6,
        "to_h":26
    },
    {
        "to_v":14,
        "iso2_code":"NZ",
        "from_h":2,
        "gaul_label":"New Zealand",
        "gaul_code":"179",
        "iso3_code":"NZL",
        "from_v":11,
        "to_h":32
    },
    {
        "to_v":6,
        "iso2_code":"ES",
        "from_h":16,
        "gaul_label":"Spain",
        "gaul_code":"229",
        "iso3_code":"ESP",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":4,
        "iso2_code":"JE",
        "from_h":17,
        "gaul_label":"Jersey",
        "gaul_code":"128",
        "iso3_code":"JEY",
        "from_v":4,
        "to_h":17
    },
    {
        "to_v":4,
        "iso2_code":"AD",
        "from_h":18,
        "gaul_label":"Andorra",
        "gaul_code":"7",
        "iso3_code":"AND",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":9,
        "iso2_code":None,
        "from_h":2,
        "gaul_label":"Jarvis Island",
        "gaul_code":"127",
        "iso3_code":None,
        "from_v":9,
        "to_h":2
    },
    {
        "to_v":5,
        "iso2_code":"AL",
        "from_h":19,
        "gaul_label":"Albania",
        "gaul_code":"3",
        "iso3_code":"ALB",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":10,
        "iso2_code":"WS",
        "from_h":1,
        "gaul_label":"Samoa",
        "gaul_code":"212",
        "iso3_code":"WSM",
        "from_v":10,
        "to_h":1
    },
    {
        "to_v":6,
        "iso2_code":"MO",
        "from_h":28,
        "gaul_label":"Macau",
        "gaul_code":"149",
        "iso3_code":"MAC",
        "from_v":6,
        "to_h":28
    },
    {
        "to_v":11,
        "iso2_code":"NF",
        "from_h":32,
        "gaul_label":"Norfolk Island",
        "gaul_code":"184",
        "iso3_code":"NFK",
        "from_v":11,
        "to_h":32
    },
    {
        "to_v":6,
        "iso2_code":"AE",
        "from_h":22,
        "gaul_label":"United Arab Emirates",
        "gaul_code":"255",
        "iso3_code":"ARE",
        "from_v":6,
        "to_h":23
    },
    {
        "to_v":7,
        "iso2_code":"GU",
        "from_h":32,
        "gaul_label":"Guam",
        "gaul_code":"101",
        "iso3_code":"GUM",
        "from_v":7,
        "to_h":32
    },
    {
        "to_v":8,
        "iso2_code":"IN",
        "from_h":24,
        "gaul_label":"India",
        "gaul_code":"115",
        "iso3_code":"IND",
        "from_v":5,
        "to_h":27
    },
    {
        "to_v":5,
        "iso2_code":"AZ",
        "from_h":21,
        "gaul_label":"Azerbaijan",
        "gaul_code":"19",
        "iso3_code":"AZE",
        "from_v":4,
        "to_h":22
    },
    {
        "to_v":12,
        "iso2_code":"LS",
        "from_h":20,
        "gaul_label":"Lesotho",
        "gaul_code":"142",
        "iso3_code":"LSO",
        "from_v":11,
        "to_h":20
    },
    {
        "to_v":6,
        "iso2_code":None,
        "from_h":2,
        "gaul_label":"Midway Island",
        "gaul_code":"164",
        "iso3_code":"MID",
        "from_v":6,
        "to_h":2
    },
    {
        "to_v":9,
        "iso2_code":"KE",
        "from_h":21,
        "gaul_label":"Kenya",
        "gaul_code":"133",
        "iso3_code":"KEN",
        "from_v":8,
        "to_h":22
    },
    {
        "to_v":5,
        "iso2_code":"TJ",
        "from_h":23,
        "gaul_label":"Tajikistan",
        "gaul_code":"239",
        "iso3_code":"TJK",
        "from_v":4,
        "to_h":23
    },
    {
        "to_v":11,
        "iso2_code":"PN",
        "from_h":6,
        "gaul_label":"Pitcairn",
        "gaul_code":"197",
        "iso3_code":"PCN",
        "from_v":11,
        "to_h":6
    },
    {
        "to_v":5,
        "iso2_code":"TR",
        "from_h":19,
        "gaul_label":"Turkey",
        "gaul_code":"249",
        "iso3_code":"TUR",
        "from_v":4,
        "to_h":21
    },
    {
        "to_v":6,
        "iso2_code":"AF",
        "from_h":22,
        "gaul_label":"Afghanistan",
        "gaul_code":"1",
        "iso3_code":"AFG",
        "from_v":5,
        "to_h":23
    },
    {
        "to_v":6,
        "iso2_code":"BD",
        "from_h":25,
        "gaul_label":"Bangladesh",
        "gaul_code":"23",
        "iso3_code":"BGD",
        "from_v":6,
        "to_h":26
    },
    {
        "to_v":7,
        "iso2_code":"MR",
        "from_h":16,
        "gaul_label":"Mauritania",
        "gaul_code":"159",
        "iso3_code":"MRT",
        "from_v":6,
        "to_h":17
    },
    {
        "to_v":10,
        "iso2_code":"SB",
        "from_h":33,
        "gaul_label":"Solomon Islands",
        "gaul_code":"225",
        "iso3_code":"SLB",
        "from_v":9,
        "to_h":34
    },
    {
        "to_v":11,
        "iso2_code":"RE",
        "from_h":23,
        "gaul_label":"R?union",
        "gaul_code":"206",
        "iso3_code":"REU",
        "from_v":11,
        "to_h":23
    },
    {
        "to_v":7,
        "iso2_code":"LC",
        "from_h":12,
        "gaul_label":"Saint Lucia",
        "gaul_code":"209",
        "iso3_code":"LCA",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":20,
        "gaul_label":"Gaza Strip",
        "gaul_code":"91",
        "iso3_code":None,
        "from_v":5,
        "to_h":20
    },
    {
        "to_v":4,
        "iso2_code":"SM",
        "from_h":18,
        "gaul_label":"San Marino",
        "gaul_code":"213",
        "iso3_code":"SMR",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":11,
        "iso2_code":"PF",
        "from_h":3,
        "gaul_label":"French Polynesia",
        "gaul_code":"87",
        "iso3_code":"PYF",
        "from_v":9,
        "to_h":5
    },
    {
        "to_v":4,
        "iso2_code":"FR",
        "from_h":17,
        "gaul_label":"France",
        "gaul_code":"85",
        "iso3_code":"FRA",
        "from_v":3,
        "to_h":18
    },
    {
        "to_v":11,
        "iso2_code":None,
        "from_h":21,
        "gaul_label":"Europa Island",
        "gaul_code":"80",
        "iso3_code":None,
        "from_v":11,
        "to_h":21
    },
    {
        "to_v":5,
        "iso2_code":"SY",
        "from_h":20,
        "gaul_label":"Syrian Arab Republic",
        "gaul_code":"238",
        "iso3_code":"SYR",
        "from_v":5,
        "to_h":21
    },
    {
        "to_v":5,
        "iso2_code":"BM",
        "from_h":12,
        "gaul_label":"Bermuda",
        "gaul_code":"30",
        "iso3_code":"BMU",
        "from_v":5,
        "to_h":12
    },
    {
        "to_v":4,
        "iso2_code":"SK",
        "from_h":19,
        "gaul_label":"Slovakia",
        "gaul_code":"223",
        "iso3_code":"SVK",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":9,
        "iso2_code":"SO",
        "from_h":22,
        "gaul_label":"Somalia",
        "gaul_code":"226",
        "iso3_code":"SOM",
        "from_v":7,
        "to_h":23
    },
    {
        "to_v":10,
        "iso2_code":"PE",
        "from_h":9,
        "gaul_label":"Peru",
        "gaul_code":"195",
        "iso3_code":"PER",
        "from_v":8,
        "to_h":11
    },
    {
        "to_v":11,
        "iso2_code":"VU",
        "from_h":33,
        "gaul_label":"Vanuatu",
        "gaul_code":"262",
        "iso3_code":"VUT",
        "from_v":10,
        "to_h":34
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":0,
        "gaul_label":"Howland Island",
        "gaul_code":"112",
        "iso3_code":None,
        "from_v":8,
        "to_h":0
    },
    {
        "to_v":10,
        "iso2_code":"SC",
        "from_h":22,
        "gaul_label":"Seychelles",
        "gaul_code":"220",
        "iso3_code":"SYC",
        "from_v":9,
        "to_h":23
    },
    {
        "to_v":6,
        "iso2_code":None,
        "from_h":21,
        "gaul_label":"Ma'tan al-Sarra",
        "gaul_code":"40762",
        "iso3_code":"XXX",
        "from_v":6,
        "to_h":21
    },
    {
        "to_v":10,
        "iso2_code":"MW",
        "from_h":21,
        "gaul_label":"Malawi",
        "gaul_code":"152",
        "iso3_code":"MWI",
        "from_v":9,
        "to_h":21
    },
    {
        "to_v":11,
        "iso2_code":"CK",
        "from_h":1,
        "gaul_label":"Cook Islands",
        "gaul_code":"60",
        "iso3_code":"COK",
        "from_v":9,
        "to_h":3
    },
    {
        "to_v":8,
        "iso2_code":"BJ",
        "from_h":18,
        "gaul_label":"Benin",
        "gaul_code":"29",
        "iso3_code":"BEN",
        "from_v":7,
        "to_h":18
    },
    {
        "to_v":6,
        "iso2_code":"EH",
        "from_h":16,
        "gaul_label":"Western Sahara",
        "gaul_code":"268",
        "iso3_code":"ESH",
        "from_v":6,
        "to_h":17
    },
    {
        "to_v":7,
        "iso2_code":"CU",
        "from_h":10,
        "gaul_label":"Cuba",
        "gaul_code":"63",
        "iso3_code":"CUB",
        "from_v":6,
        "to_h":11
    },
    {
        "to_v":6,
        "iso2_code":"IR",
        "from_h":21,
        "gaul_label":"Iran  (Islamic Republic of)",
        "gaul_code":"117",
        "iso3_code":"IRN",
        "from_v":5,
        "to_h":23
    },
    {
        "to_v":4,
        "iso2_code":"ME",
        "from_h":19,
        "gaul_label":"Montenegro",
        "gaul_code":"2647",
        "iso3_code":"MNE",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":14,
        "iso2_code":"FK",
        "from_h":14,
        "gaul_label":"Falkland Islands (Malvinas)",
        "gaul_code":"81",
        "iso3_code":"FLK",
        "from_v":14,
        "to_h":14
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":29,
        "gaul_label":"Spratly Islands",
        "gaul_code":"230",
        "iso3_code":None,
        "from_v":7,
        "to_h":29
    },
    {
        "to_v":11,
        "iso2_code":None,
        "from_h":21,
        "gaul_label":"Bassas da India",
        "gaul_code":"25",
        "iso3_code":None,
        "from_v":11,
        "to_h":21
    },
    {
        "to_v":10,
        "iso2_code":"YT",
        "from_h":22,
        "gaul_label":"Mayotte",
        "gaul_code":"161",
        "iso3_code":"MYT",
        "from_v":10,
        "to_h":22
    },
    {
        "to_v":14,
        "iso2_code":"HM",
        "from_h":22,
        "gaul_label":"Heard Island and McDonald Islands",
        "gaul_code":"109",
        "iso3_code":"HMD",
        "from_v":14,
        "to_h":22
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":23,
        "gaul_label":"China",
        "gaul_code":"147295",
        "iso3_code":None,
        "from_v":3,
        "to_h":28
    },
    {
        "to_v":5,
        "iso2_code":"AM",
        "from_h":21,
        "gaul_label":"Armenia",
        "gaul_code":"13",
        "iso3_code":"ARM",
        "from_v":4,
        "to_h":21
    },
    {
        "to_v":5,
        "iso2_code":"KR",
        "from_h":27,
        "gaul_label":"Republic of Korea",
        "gaul_code":"202",
        "iso3_code":"KOR",
        "from_v":5,
        "to_h":28
    },
    {
        "to_v":7,
        "iso2_code":"DO",
        "from_h":11,
        "gaul_label":"Dominican Republic",
        "gaul_code":"72",
        "iso3_code":"DOM",
        "from_v":6,
        "to_h":11
    },
    {
        "to_v":4,
        "iso2_code":"UA",
        "from_h":19,
        "gaul_label":"Ukraine",
        "gaul_code":"254",
        "iso3_code":"UKR",
        "from_v":3,
        "to_h":20
    },
    {
        "to_v":5,
        "iso2_code":"KP",
        "from_h":27,
        "gaul_label":"Dem People's Rep of Korea",
        "gaul_code":"67",
        "iso3_code":"PRK",
        "from_v":4,
        "to_h":28
    },
    {
        "to_v":11,
        "iso2_code":"TO",
        "from_h":1,
        "gaul_label":"Tonga",
        "gaul_code":"245",
        "iso3_code":"TON",
        "from_v":10,
        "to_h":1
    },
    {
        "to_v":3,
        "iso2_code":"FI",
        "from_h":18,
        "gaul_label":"Finland",
        "gaul_code":"84",
        "iso3_code":"FIN",
        "from_v":1,
        "to_h":19
    },
    {
        "to_v":10,
        "iso2_code":None,
        "from_h":23,
        "gaul_label":"Tromelin Island",
        "gaul_code":"247",
        "iso3_code":None,
        "from_v":10,
        "to_h":23
    },
    {
        "to_v":7,
        "iso2_code":"LY",
        "from_h":18,
        "gaul_label":"Libya",
        "gaul_code":"145",
        "iso3_code":"LBY",
        "from_v":5,
        "to_h":20
    },
    {
        "to_v":7,
        "iso2_code":"KY",
        "from_h":10,
        "gaul_label":"Cayman Islands",
        "gaul_code":"48",
        "iso3_code":"CYM",
        "from_v":7,
        "to_h":10
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":28,
        "gaul_label":"Paracel Islands",
        "gaul_code":"193",
        "iso3_code":None,
        "from_v":7,
        "to_h":28
    },
    {
        "to_v":8,
        "iso2_code":"CF",
        "from_h":19,
        "gaul_label":"Central African Republic",
        "gaul_code":"49",
        "iso3_code":"CAF",
        "from_v":7,
        "to_h":20
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":20,
        "gaul_label":"West Bank",
        "gaul_code":"267",
        "iso3_code":None,
        "from_v":5,
        "to_h":21
    },
    {
        "to_v":11,
        "iso2_code":"NC",
        "from_h":32,
        "gaul_label":"New Caledonia",
        "gaul_code":"178",
        "iso3_code":"NCL",
        "from_v":10,
        "to_h":33
    },
    {
        "to_v":11,
        "iso2_code":"MU",
        "from_h":23,
        "gaul_label":"Mauritius",
        "gaul_code":"160",
        "iso3_code":"MUS",
        "from_v":10,
        "to_h":23
    },
    {
        "to_v":4,
        "iso2_code":"LI",
        "from_h":18,
        "gaul_label":"Liechtenstein",
        "gaul_code":"146",
        "iso3_code":"LIE",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":3,
        "iso2_code":"BY",
        "from_h":19,
        "gaul_label":"Belarus",
        "gaul_code":"26",
        "iso3_code":"BLR",
        "from_v":3,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":"VG",
        "from_h":11,
        "gaul_label":"British Virgin Islands",
        "gaul_code":"39",
        "iso3_code":"VGB",
        "from_v":7,
        "to_h":11
    },
    {
        "to_v":7,
        "iso2_code":"ML",
        "from_h":16,
        "gaul_label":"Mali",
        "gaul_code":"155",
        "iso3_code":"MLI",
        "from_v":6,
        "to_h":18
    },
    {
        "to_v":3,
        "iso2_code":"SE",
        "from_h":18,
        "gaul_label":"Sweden",
        "gaul_code":"236",
        "iso3_code":"SWE",
        "from_v":2,
        "to_h":19
    },
    {
        "to_v":4,
        "iso2_code":"PL",
        "from_h":18,
        "gaul_label":"Poland",
        "gaul_code":"198",
        "iso3_code":"POL",
        "from_v":3,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":"CV",
        "from_h":15,
        "gaul_label":"Cape Verde",
        "gaul_code":"47",
        "iso3_code":"CPV",
        "from_v":7,
        "to_h":15
    },
    {
        "to_v":4,
        "iso2_code":"BG",
        "from_h":19,
        "gaul_label":"Bulgaria",
        "gaul_code":"41",
        "iso3_code":"BGR",
        "from_v":4,
        "to_h":20
    },
    {
        "to_v":4,
        "iso2_code":"RO",
        "from_h":19,
        "gaul_label":"Romania",
        "gaul_code":"203",
        "iso3_code":"ROU",
        "from_v":4,
        "to_h":20
    },
    {
        "to_v":10,
        "iso2_code":"AO",
        "from_h":19,
        "gaul_label":"Angola",
        "gaul_code":"8",
        "iso3_code":"AGO",
        "from_v":9,
        "to_h":20
    },
    {
        "to_v":8,
        "iso2_code":"TD",
        "from_h":19,
        "gaul_label":"Chad",
        "gaul_code":"50",
        "iso3_code":"TCD",
        "from_v":6,
        "to_h":20
    },
    {
        "to_v":13,
        "iso2_code":"TF",
        "from_h":21,
        "gaul_label":"French Southern and Antarctic Territories",
        "gaul_code":"88",
        "iso3_code":"ATF",
        "from_v":12,
        "to_h":24
    },
    {
        "to_v":9,
        "iso2_code":"TK",
        "from_h":0,
        "gaul_label":"Tokelau",
        "gaul_code":"244",
        "iso3_code":"TKL",
        "from_v":9,
        "to_h":1
    },
    {
        "to_v":5,
        "iso2_code":"CY",
        "from_h":20,
        "gaul_label":"Cyprus",
        "gaul_code":"64",
        "iso3_code":"CYP",
        "from_v":5,
        "to_h":20
    },
    {
        "to_v":14,
        "iso2_code":"GS",
        "from_h":15,
        "gaul_label":"South Georgia and the South Sandwich Islands",
        "gaul_code":"228",
        "iso3_code":"SGS",
        "from_v":14,
        "to_h":16
    },
    {
        "to_v":7,
        "iso2_code":"YE",
        "from_h":22,
        "gaul_label":"Yemen",
        "gaul_code":"269",
        "iso3_code":"YEM",
        "from_v":7,
        "to_h":23
    },
    {
        "to_v":8,
        "iso2_code":"BN",
        "from_h":29,
        "gaul_label":"Brunei Darussalam",
        "gaul_code":"40",
        "iso3_code":"BRN",
        "from_v":8,
        "to_h":29
    },
    {
        "to_v":6,
        "iso2_code":"QA",
        "from_h":22,
        "gaul_label":"Qatar",
        "gaul_code":"201",
        "iso3_code":"QAT",
        "from_v":6,
        "to_h":22
    },
    {
        "to_v":8,
        "iso2_code":"MY",
        "from_h":27,
        "gaul_label":"Malaysia",
        "gaul_code":"153",
        "iso3_code":"MYS",
        "from_v":8,
        "to_h":29
    },
    {
        "to_v":4,
        "iso2_code":"AT",
        "from_h":18,
        "gaul_label":"Austria",
        "gaul_code":"18",
        "iso3_code":"AUT",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":7,
        "gaul_label":"Clipperton Island",
        "gaul_code":"55",
        "iso3_code":None,
        "from_v":7,
        "to_h":7
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":0,
        "gaul_label":"Baker Island",
        "gaul_code":"22",
        "iso3_code":"UMI",
        "from_v":8,
        "to_h":0
    },
    {
        "to_v":9,
        "iso2_code":"UG",
        "from_h":20,
        "gaul_label":"Uganda",
        "gaul_code":"253",
        "iso3_code":"UGA",
        "from_v":8,
        "to_h":21
    },
    {
        "to_v":4,
        "iso2_code":"HU",
        "from_h":19,
        "gaul_label":"Hungary",
        "gaul_code":"113",
        "iso3_code":"HUN",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":"NE",
        "from_h":18,
        "gaul_label":"Niger",
        "gaul_code":"181",
        "iso3_code":"NER",
        "from_v":6,
        "to_h":19
    },
    {
        "to_v":3,
        "iso2_code":"IM",
        "from_h":17,
        "gaul_label":"Isle of Man",
        "gaul_code":"120",
        "iso3_code":"IMN",
        "from_v":3,
        "to_h":17
    },
    {
        "to_v":10,
        "iso2_code":None,
        "from_h":22,
        "gaul_label":"Juan de Nova Island",
        "gaul_code":"131",
        "iso3_code":None,
        "from_v":10,
        "to_h":22
    },
    {
        "to_v":12,
        "iso2_code":"BR",
        "from_h":10,
        "gaul_label":"Brazil",
        "gaul_code":"37",
        "iso3_code":"BRA",
        "from_v":8,
        "to_h":15
    },
    {
        "to_v":6,
        "iso2_code":None,
        "from_h":21,
        "gaul_label":"Hala'ib triangle",
        "gaul_code":"40760",
        "iso3_code":"XXX",
        "from_v":6,
        "to_h":21
    },
    {
        "to_v":2,
        "iso2_code":"FO",
        "from_h":17,
        "gaul_label":"Faroe Islands",
        "gaul_code":"82",
        "iso3_code":"FRO",
        "from_v":2,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"GN",
        "from_h":16,
        "gaul_label":"Guinea",
        "gaul_code":"106",
        "iso3_code":"GIN",
        "from_v":7,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"PA",
        "from_h":9,
        "gaul_label":"Panama",
        "gaul_code":"191",
        "iso3_code":"PAN",
        "from_v":8,
        "to_h":10
    },
    {
        "to_v":8,
        "iso2_code":"CR",
        "from_h":9,
        "gaul_label":"Costa Rica",
        "gaul_code":"61",
        "iso3_code":"CRI",
        "from_v":7,
        "to_h":9
    },
    {
        "to_v":4,
        "iso2_code":"LU",
        "from_h":18,
        "gaul_label":"Luxembourg",
        "gaul_code":"148",
        "iso3_code":"LUX",
        "from_v":3,
        "to_h":18
    },
    {
        "to_v":10,
        "iso2_code":"AS",
        "from_h":1,
        "gaul_label":"American Samoa",
        "gaul_code":"5",
        "iso3_code":"ASM",
        "from_v":10,
        "to_h":1
    },
    {
        "to_v":6,
        "iso2_code":"BS",
        "from_h":10,
        "gaul_label":"Bahamas",
        "gaul_code":"20",
        "iso3_code":"BHS",
        "from_v":6,
        "to_h":11
    },
    {
        "to_v":7,
        "iso2_code":"VC",
        "from_h":12,
        "gaul_label":"Saint Vincent and the Grenadines",
        "gaul_code":"211",
        "iso3_code":"VCT",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":3,
        "iso2_code":"NO",
        "from_h":18,
        "gaul_label":"Norway",
        "gaul_code":"186",
        "iso3_code":"NOR",
        "from_v":1,
        "to_h":19
    },
    {
        "to_v":5,
        "iso2_code":"GI",
        "from_h":17,
        "gaul_label":"Gibraltar",
        "gaul_code":"95",
        "iso3_code":"GIB",
        "from_v":5,
        "to_h":17
    },
    {
        "to_v":3,
        "iso2_code":"IE",
        "from_h":17,
        "gaul_label":"Ireland",
        "gaul_code":"119",
        "iso3_code":"IRL",
        "from_v":3,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"GH",
        "from_h":17,
        "gaul_label":"Ghana",
        "gaul_code":"94",
        "iso3_code":"GHA",
        "from_v":7,
        "to_h":18
    },
    {
        "to_v":8,
        "iso2_code":"PW",
        "from_h":31,
        "gaul_label":"Palau",
        "gaul_code":"189",
        "iso3_code":"PLW",
        "from_v":8,
        "to_h":31
    },
    {
        "to_v":8,
        "iso2_code":"NG",
        "from_h":18,
        "gaul_label":"Nigeria",
        "gaul_code":"182",
        "iso3_code":"NGA",
        "from_v":7,
        "to_h":19
    },
    {
        "to_v":9,
        "iso2_code":"EC",
        "from_h":8,
        "gaul_label":"Ecuador",
        "gaul_code":"73",
        "iso3_code":"ECU",
        "from_v":8,
        "to_h":10
    },
    {
        "to_v":4,
        "iso2_code":"CZ",
        "from_h":18,
        "gaul_label":"Czech Republic",
        "gaul_code":"65",
        "iso3_code":"CZE",
        "from_v":3,
        "to_h":19
    },
    {
        "to_v":8,
        "iso2_code":"VN",
        "from_h":27,
        "gaul_label":"Viet Nam",
        "gaul_code":"264",
        "iso3_code":"VNM",
        "from_v":6,
        "to_h":28
    },
    {
        "to_v":13,
        "iso2_code":"AU",
        "from_h":27,
        "gaul_label":"Australia",
        "gaul_code":"17",
        "iso3_code":"AUS",
        "from_v":9,
        "to_h":32
    },
    {
        "to_v":7,
        "iso2_code":"DZ",
        "from_h":17,
        "gaul_label":"Algeria",
        "gaul_code":"4",
        "iso3_code":"DZA",
        "from_v":5,
        "to_h":19
    },
    {
        "to_v":4,
        "iso2_code":"SI",
        "from_h":18,
        "gaul_label":"Slovenia",
        "gaul_code":"224",
        "iso3_code":"SVN",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":"SV",
        "from_h":9,
        "gaul_label":"El Salvador",
        "gaul_code":"75",
        "iso3_code":"SLV",
        "from_v":7,
        "to_h":9
    },
    {
        "to_v":9,
        "iso2_code":"TV",
        "from_h":35,
        "gaul_label":"Tuvalu",
        "gaul_code":"252",
        "iso3_code":"TUV",
        "from_v":9,
        "to_h":35
    },
    {
        "to_v":8,
        "iso2_code":"CI",
        "from_h":17,
        "gaul_label":"C?te d'Ivoire",
        "gaul_code":"66",
        "iso3_code":"CIV",
        "from_v":7,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":21,
        "gaul_label":"Ilemi triangle",
        "gaul_code":"61013",
        "iso3_code":None,
        "from_v":8,
        "to_h":21
    },
    {
        "to_v":14,
        "iso2_code":"CL",
        "from_h":8,
        "gaul_label":"Chile",
        "gaul_code":"51",
        "iso3_code":"CHL",
        "from_v":10,
        "to_h":14
    },
    {
        "to_v":8,
        "iso2_code":"MH",
        "from_h":34,
        "gaul_label":"Marshall Islands",
        "gaul_code":"157",
        "iso3_code":"MHL",
        "from_v":7,
        "to_h":35
    },
    {
        "to_v":4,
        "iso2_code":"BE",
        "from_h":18,
        "gaul_label":"Belgium",
        "gaul_code":"27",
        "iso3_code":"BEL",
        "from_v":3,
        "to_h":18
    },
    {
        "to_v":9,
        "iso2_code":"KI",
        "from_h":0,
        "gaul_label":"Kiribati",
        "gaul_code":"135",
        "iso3_code":"KIR",
        "from_v":8,
        "to_h":35
    },
    {
        "to_v":7,
        "iso2_code":"HT",
        "from_h":10,
        "gaul_label":"Haiti",
        "gaul_code":"108",
        "iso3_code":"HTI",
        "from_v":6,
        "to_h":11
    },
    {
        "to_v":7,
        "iso2_code":"BZ",
        "from_h":9,
        "gaul_label":"Belize",
        "gaul_code":"28",
        "iso3_code":"BLZ",
        "from_v":7,
        "to_h":9
    },
    {
        "to_v":6,
        "iso2_code":"HK",
        "from_h":28,
        "gaul_label":"Hong Kong",
        "gaul_code":"33364",
        "iso3_code":"HKG",
        "from_v":6,
        "to_h":28
    },
    {
        "to_v":8,
        "iso2_code":"SL",
        "from_h":16,
        "gaul_label":"Sierra Leone",
        "gaul_code":"221",
        "iso3_code":"SLE",
        "from_v":7,
        "to_h":17
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":1,
        "gaul_label":"Johnston Atoll",
        "gaul_code":"129",
        "iso3_code":"JTN",
        "from_v":7,
        "to_h":1
    },
    {
        "to_v":4,
        "iso2_code":"GE",
        "from_h":20,
        "gaul_label":"Georgia",
        "gaul_code":"92",
        "iso3_code":"GEO",
        "from_v":4,
        "to_h":21
    },
    {
        "to_v":7,
        "iso2_code":"LA",
        "from_h":27,
        "gaul_label":"Lao People's Democratic Republic",
        "gaul_code":"139",
        "iso3_code":"LAO",
        "from_v":6,
        "to_h":28
    },
    {
        "to_v":3,
        "iso2_code":"DK",
        "from_h":18,
        "gaul_label":"Denmark",
        "gaul_code":"69",
        "iso3_code":"DNK",
        "from_v":3,
        "to_h":18
    },
    {
        "to_v":8,
        "iso2_code":"PH",
        "from_h":29,
        "gaul_label":"Philippines",
        "gaul_code":"196",
        "iso3_code":"PHL",
        "from_v":6,
        "to_h":30
    },
    {
        "to_v":7,
        "iso2_code":"PR",
        "from_h":11,
        "gaul_label":"Puerto Rico",
        "gaul_code":"200",
        "iso3_code":"PRI",
        "from_v":7,
        "to_h":11
    },
    {
        "to_v":6,
        "iso2_code":"MA",
        "from_h":16,
        "gaul_label":"Morocco",
        "gaul_code":"169",
        "iso3_code":"MAR",
        "from_v":5,
        "to_h":17
    },
    {
        "to_v":4,
        "iso2_code":"HR",
        "from_h":18,
        "gaul_label":"Croatia",
        "gaul_code":"62",
        "iso3_code":"HRV",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":4,
        "iso2_code":"MN",
        "from_h":23,
        "gaul_label":"Mongolia",
        "gaul_code":"167",
        "iso3_code":"MNG",
        "from_v":3,
        "to_h":26
    },
    {
        "to_v":4,
        "iso2_code":"GG",
        "from_h":17,
        "gaul_label":"Guernsey",
        "gaul_code":"104",
        "iso3_code":"GGY",
        "from_v":4,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"TH",
        "from_h":27,
        "gaul_label":"Thailand",
        "gaul_code":"240",
        "iso3_code":"THA",
        "from_v":6,
        "to_h":28
    },
    {
        "to_v":11,
        "iso2_code":"NA",
        "from_h":19,
        "gaul_label":"Namibia",
        "gaul_code":"172",
        "iso3_code":"NAM",
        "from_v":10,
        "to_h":20
    },
    {
        "to_v":7,
        "iso2_code":"GD",
        "from_h":11,
        "gaul_label":"Grenada",
        "gaul_code":"99",
        "iso3_code":"GRD",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":4,
        "iso2_code":"KW",
        "from_h":28,
        "gaul_label":"Kuril islands",
        "gaul_code":"136",
        "iso3_code":None,
        "from_v":4,
        "to_h":28
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":10,
        "gaul_label":"Navassa Island",
        "gaul_code":"174",
        "iso3_code":"XXX",
        "from_v":7,
        "to_h":10
    },
    {
        "to_v":6,
        "iso2_code":"IQ",
        "from_h":21,
        "gaul_label":"Iraq",
        "gaul_code":"118",
        "iso3_code":"IRQ",
        "from_v":5,
        "to_h":22
    },
    {
        "to_v":5,
        "iso2_code":"PT",
        "from_h":17,
        "gaul_label":"Portugal",
        "gaul_code":"199",
        "iso3_code":"PRT",
        "from_v":4,
        "to_h":17
    },
    {
        "to_v":3,
        "iso2_code":"EE",
        "from_h":19,
        "gaul_label":"Estonia",
        "gaul_code":"78",
        "iso3_code":"EST",
        "from_v":3,
        "to_h":19
    },
    {
        "to_v":12,
        "iso2_code":"UY",
        "from_h":13,
        "gaul_label":"Uruguay",
        "gaul_code":"260",
        "iso3_code":"URY",
        "from_v":12,
        "to_h":13
    },
    {
        "to_v":9,
        "iso2_code":"GQ",
        "from_h":18,
        "gaul_label":"Equatorial Guinea",
        "gaul_code":"76",
        "iso3_code":"GNQ",
        "from_v":8,
        "to_h":19
    },
    {
        "to_v":5,
        "iso2_code":"LB",
        "from_h":20,
        "gaul_label":"Lebanon",
        "gaul_code":"141",
        "iso3_code":"LBN",
        "from_v":5,
        "to_h":21
    },
    {
        "to_v":13,
        "iso2_code":"ZA",
        "from_h":19,
        "gaul_label":"South Africa",
        "gaul_code":"227",
        "iso3_code":"ZAF",
        "from_v":11,
        "to_h":20
    },
    {
        "to_v":5,
        "iso2_code":"UZ",
        "from_h":21,
        "gaul_label":"Uzbekistan",
        "gaul_code":"261",
        "iso3_code":"UZB",
        "from_v":4,
        "to_h":23
    },
    {
        "to_v":5,
        "iso2_code":"TN",
        "from_h":18,
        "gaul_label":"Tunisia",
        "gaul_code":"248",
        "iso3_code":"TUN",
        "from_v":5,
        "to_h":18
    },
    {
        "to_v":7,
        "iso2_code":"DJ",
        "from_h":22,
        "gaul_label":"Djibouti",
        "gaul_code":"70",
        "iso3_code":"DJI",
        "from_v":7,
        "to_h":22
    },
    {
        "to_v":3,
        "iso2_code":"GL",
        "from_h":15,
        "gaul_label":"Greenland",
        "gaul_code":"98",
        "iso3_code":"GRL",
        "from_v":0,
        "to_h":18
    },
    {
        "to_v":7,
        "iso2_code":"AG",
        "from_h":12,
        "gaul_label":"Antigua and Barbuda",
        "gaul_code":"11",
        "iso3_code":"ATG",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":16,
        "gaul_label":"Madeira Islands",
        "gaul_code":"151",
        "iso3_code":None,
        "from_v":5,
        "to_h":16
    },
    {
        "to_v":9,
        "iso2_code":"CO",
        "from_h":9,
        "gaul_label":"Colombia",
        "gaul_code":"57",
        "iso3_code":"COL",
        "from_v":7,
        "to_h":11
    },
    {
        "to_v":9,
        "iso2_code":"BI",
        "from_h":20,
        "gaul_label":"Burundi",
        "gaul_code":"43",
        "iso3_code":"BDI",
        "from_v":9,
        "to_h":21
    },
    {
        "to_v":6,
        "iso2_code":None,
        "from_h":28,
        "gaul_label":"Taiwan",
        "gaul_code":"147296",
        "iso3_code":None,
        "from_v":6,
        "to_h":29
    },
    {
        "to_v":11,
        "iso2_code":"FJ",
        "from_h":0,
        "gaul_label":"Fiji",
        "gaul_code":"83",
        "iso3_code":"FJI",
        "from_v":10,
        "to_h":35
    },
    {
        "to_v":7,
        "iso2_code":"BB",
        "from_h":12,
        "gaul_label":"Barbados",
        "gaul_code":"24",
        "iso3_code":"BRB",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":1,
        "gaul_label":"Palmyra Atoll",
        "gaul_code":"190",
        "iso3_code":"XXX",
        "from_v":8,
        "to_h":1
    },
    {
        "to_v":11,
        "iso2_code":"MG",
        "from_h":21,
        "gaul_label":"Madagascar",
        "gaul_code":"150",
        "iso3_code":"MDG",
        "from_v":10,
        "to_h":22
    },
    {
        "to_v":5,
        "iso2_code":"IT",
        "from_h":18,
        "gaul_label":"Italy",
        "gaul_code":"122",
        "iso3_code":"ITA",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":6,
        "iso2_code":"BT",
        "from_h":25,
        "gaul_label":"Bhutan",
        "gaul_code":"31",
        "iso3_code":"BTN",
        "from_v":6,
        "to_h":26
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":20,
        "gaul_label":"Sudan",
        "gaul_code":"6",
        "iso3_code":"SDN",
        "from_v":6,
        "to_h":21
    },
    {
        "to_v":6,
        "iso2_code":"NP",
        "from_h":24,
        "gaul_label":"Nepal",
        "gaul_code":"175",
        "iso3_code":"NPL",
        "from_v":5,
        "to_h":25
    },
    {
        "to_v":5,
        "iso2_code":"MT",
        "from_h":19,
        "gaul_label":"Malta",
        "gaul_code":"156",
        "iso3_code":"MLT",
        "from_v":5,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":29,
        "gaul_label":"Scarborough Reef",
        "gaul_code":"216",
        "iso3_code":None,
        "from_v":7,
        "to_h":29
    },
    {
        "to_v":10,
        "iso2_code":"CD",
        "from_h":19,
        "gaul_label":"Democratic Republic of the Congo",
        "gaul_code":"68",
        "iso3_code":"COD",
        "from_v":8,
        "to_h":21
    },
    {
        "to_v":3,
        "iso2_code":"NL",
        "from_h":18,
        "gaul_label":"Netherlands",
        "gaul_code":"177",
        "iso3_code":"NLD",
        "from_v":3,
        "to_h":18
    },
    {
        "to_v":7,
        "iso2_code":"MP",
        "from_h":31,
        "gaul_label":"Northern Mariana Islands",
        "gaul_code":"185",
        "iso3_code":"MNP",
        "from_v":6,
        "to_h":32
    },
    {
        "to_v":8,
        "iso2_code":"SR",
        "from_h":12,
        "gaul_label":"Suriname",
        "gaul_code":"233",
        "iso3_code":"SUR",
        "from_v":8,
        "to_h":12
    },
    {
        "to_v":7,
        "iso2_code":"AI",
        "from_h":12,
        "gaul_label":"Anguilla",
        "gaul_code":"9",
        "iso3_code":"AIA",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":6,
        "iso2_code":"TC",
        "from_h":11,
        "gaul_label":"Turks and Caicos islands",
        "gaul_code":"251",
        "iso3_code":"TCA",
        "from_v":6,
        "to_h":11
    },
    {
        "to_v":9,
        "iso2_code":"NR",
        "from_h":34,
        "gaul_label":"Nauru",
        "gaul_code":"173",
        "iso3_code":"NRU",
        "from_v":9,
        "to_h":34
    },
    {
        "to_v":8,
        "iso2_code":"FM",
        "from_h":31,
        "gaul_label":"Micronesia (Federated States of)",
        "gaul_code":"163",
        "iso3_code":"FSM",
        "from_v":7,
        "to_h":34
    },
    {
        "to_v":4,
        "iso2_code":"VA",
        "from_h":18,
        "gaul_label":"Holy See",
        "gaul_code":"110",
        "iso3_code":"VAT",
        "from_v":4,
        "to_h":18
    },
    {
        "to_v":4,
        "iso2_code":"MK",
        "from_h":19,
        "gaul_label":"The former Yugoslav Republic of Macedonia",
        "gaul_code":"241",
        "iso3_code":"MKD",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":6,
        "iso2_code":"IL",
        "from_h":20,
        "gaul_label":"Israel",
        "gaul_code":"121",
        "iso3_code":"ISR",
        "from_v":5,
        "to_h":21
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":23,
        "gaul_label":"Jammu and Kashmir",
        "gaul_code":"40781",
        "iso3_code":None,
        "from_v":5,
        "to_h":24
    },
    {
        "to_v":7,
        "iso2_code":"WK",
        "from_h":33,
        "gaul_label":"Wake Island",
        "gaul_code":"265",
        "iso3_code":"WAK",
        "from_v":7,
        "to_h":33
    },
    {
        "to_v":10,
        "iso2_code":"ID",
        "from_h":27,
        "gaul_label":"Indonesia",
        "gaul_code":"116",
        "iso3_code":"IDN",
        "from_v":8,
        "to_h":32
    },
    {
        "to_v":2,
        "iso2_code":"IS",
        "from_h":17,
        "gaul_label":"Iceland",
        "gaul_code":"114",
        "iso3_code":"ISL",
        "from_v":2,
        "to_h":17
    },
    {
        "to_v":8,
        "iso2_code":"VE",
        "from_h":10,
        "gaul_label":"Venezuela",
        "gaul_code":"263",
        "iso3_code":"VEN",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":7,
        "iso2_code":"SN",
        "from_h":16,
        "gaul_label":"Senegal",
        "gaul_code":"217",
        "iso3_code":"SEN",
        "from_v":7,
        "to_h":16
    },
    {
        "to_v":10,
        "iso2_code":"PG",
        "from_h":31,
        "gaul_label":"Papua New Guinea",
        "gaul_code":"192",
        "iso3_code":"PNG",
        "from_v":9,
        "to_h":33
    },
    {
        "to_v":7,
        "iso2_code":"KN",
        "from_h":12,
        "gaul_label":"Saint Kitts and Nevis",
        "gaul_code":"208",
        "iso3_code":"KNA",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":7,
        "iso2_code":"TT",
        "from_h":11,
        "gaul_label":"Trinidad and Tobago",
        "gaul_code":"246",
        "iso3_code":"TTO",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":11,
        "iso2_code":"ZW",
        "from_h":20,
        "gaul_label":"Zimbabwe",
        "gaul_code":"271",
        "iso3_code":"ZWE",
        "from_v":10,
        "to_h":21
    },
    {
        "to_v":4,
        "iso2_code":"DE",
        "from_h":18,
        "gaul_label":"Germany",
        "gaul_code":"93",
        "iso3_code":"DEU",
        "from_v":3,
        "to_h":18
    },
    {
        "to_v":7,
        "iso2_code":"GM",
        "from_h":16,
        "gaul_label":"Gambia",
        "gaul_code":"90",
        "iso3_code":"GMB",
        "from_v":7,
        "to_h":16
    },
    {
        "to_v":11,
        "iso2_code":"MZ",
        "from_h":20,
        "gaul_label":"Mozambique",
        "gaul_code":"170",
        "iso3_code":"MOZ",
        "from_v":10,
        "to_h":22
    },
    {
        "to_v":4,
        "iso2_code":"PM",
        "from_h":14,
        "gaul_label":"Saint Pierre et Miquelon",
        "gaul_code":"210",
        "iso3_code":"SPM",
        "from_v":4,
        "to_h":14
    },
    {
        "to_v":4,
        "iso2_code":"KZ",
        "from_h":21,
        "gaul_label":"Kazakhstan",
        "gaul_code":"132",
        "iso3_code":"KAZ",
        "from_v":3,
        "to_h":23
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":24,
        "gaul_label":"Aksai Chin",
        "gaul_code":"2",
        "iso3_code":None,
        "from_v":5,
        "to_h":24
    },
    {
        "to_v":7,
        "iso2_code":"ER",
        "from_h":21,
        "gaul_label":"Eritrea",
        "gaul_code":"77",
        "iso3_code":"ERI",
        "from_v":7,
        "to_h":22
    },
    {
        "to_v":5,
        "iso2_code":None,
        "from_h":23,
        "gaul_label":"Kyrgyzstan",
        "gaul_code":"138",
        "iso3_code":"KGZ",
        "from_v":4,
        "to_h":23
    },
    {
        "to_v":10,
        "iso2_code":None,
        "from_h":22,
        "gaul_label":"Glorioso Island",
        "gaul_code":"96",
        "iso3_code":None,
        "from_v":10,
        "to_h":22
    },
    {
        "to_v":6,
        "iso2_code":None,
        "from_h":29,
        "gaul_label":"Senkaku Islands",
        "gaul_code":"218",
        "iso3_code":None,
        "from_v":6,
        "to_h":29
    },
    {
        "to_v":9,
        "iso2_code":"IO",
        "from_h":25,
        "gaul_label":"British Indian Ocean Territory",
        "gaul_code":"38",
        "iso3_code":"IOT",
        "from_v":9,
        "to_h":25
    },
    {
        "to_v":7,
        "iso2_code":"MS",
        "from_h":12,
        "gaul_label":"Montserrat",
        "gaul_code":"168",
        "iso3_code":"MSR",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":7,
        "iso2_code":"MX",
        "from_h":7,
        "gaul_label":"Mexico",
        "gaul_code":"162",
        "iso3_code":"MEX",
        "from_v":5,
        "to_h":9
    },
    {
        "to_v":8,
        "iso2_code":"LK",
        "from_h":25,
        "gaul_label":"Sri Lanka",
        "gaul_code":"231",
        "iso3_code":"LKA",
        "from_v":8,
        "to_h":26
    },
    {
        "to_v":3,
        "iso2_code":"LV",
        "from_h":19,
        "gaul_label":"Latvia",
        "gaul_code":"140",
        "iso3_code":"LVA",
        "from_v":3,
        "to_h":19
    },
    {
        "to_v":8,
        "iso2_code":None,
        "from_h":20,
        "gaul_label":"South Sudan",
        "gaul_code":"74",
        "iso3_code":"SSD",
        "from_v":7,
        "to_h":21
    },
    {
        "to_v":8,
        "iso2_code":"GY",
        "from_h":11,
        "gaul_label":"Guyana",
        "gaul_code":"107",
        "iso3_code":"GUY",
        "from_v":8,
        "to_h":12
    },
    {
        "to_v":7,
        "iso2_code":"GP",
        "from_h":12,
        "gaul_label":"Guadeloupe",
        "gaul_code":"100",
        "iso3_code":"GLP",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":7,
        "iso2_code":"HN",
        "from_h":9,
        "gaul_label":"Honduras",
        "gaul_code":"111",
        "iso3_code":"HND",
        "from_v":7,
        "to_h":10
    },
    {
        "to_v":8,
        "iso2_code":"MM",
        "from_h":26,
        "gaul_label":"Myanmar",
        "gaul_code":"171",
        "iso3_code":"MMR",
        "from_v":6,
        "to_h":27
    },
    {
        "to_v":14,
        "iso2_code":"BV",
        "from_h":18,
        "gaul_label":"Bouvet Island",
        "gaul_code":"36",
        "iso3_code":"BVT",
        "from_v":14,
        "to_h":18
    },
    {
        "to_v":6,
        "iso2_code":"EG",
        "from_h":20,
        "gaul_label":"Egypt",
        "gaul_code":"40765",
        "iso3_code":"EGY",
        "from_v":5,
        "to_h":21
    },
    {
        "to_v":7,
        "iso2_code":"NI",
        "from_h":9,
        "gaul_label":"Nicaragua",
        "gaul_code":"180",
        "iso3_code":"NIC",
        "from_v":7,
        "to_h":10
    },
    {
        "to_v":8,
        "iso2_code":"SG",
        "from_h":28,
        "gaul_label":"Singapore",
        "gaul_code":"222",
        "iso3_code":"SGP",
        "from_v":8,
        "to_h":28
    },
    {
        "to_v":4,
        "iso2_code":"RS",
        "from_h":19,
        "gaul_label":"Serbia",
        "gaul_code":"2648",
        "iso3_code":"SRB",
        "from_v":4,
        "to_h":19
    },
    {
        "to_v":11,
        "iso2_code":"BW",
        "from_h":19,
        "gaul_label":"Botswana",
        "gaul_code":"35",
        "iso3_code":"BWA",
        "from_v":10,
        "to_h":20
    },
    {
        "to_v":9,
        "iso2_code":"TL",
        "from_h":30,
        "gaul_label":"Timor-Leste",
        "gaul_code":"242",
        "iso3_code":"TLS",
        "from_v":9,
        "to_h":30
    },
    {
        "to_v":17,
        "iso2_code":"AQ",
        "from_h":14,
        "gaul_label":"Antarctica",
        "gaul_code":"10",
        "iso3_code":"ATA",
        "from_v":15,
        "to_h":24
    },
    {
        "to_v":9,
        "iso2_code":"CG",
        "from_h":19,
        "gaul_label":"Congo",
        "gaul_code":"59",
        "iso3_code":"COG",
        "from_v":8,
        "to_h":19
    },
    {
        "to_v":7,
        "iso2_code":"AN",
        "from_h":11,
        "gaul_label":"Netherlands Antilles",
        "gaul_code":"176",
        "iso3_code":"ANT",
        "from_v":7,
        "to_h":12
    },
    {
        "to_v":5,
        "iso2_code":"GR",
        "from_h":19,
        "gaul_label":"Greece",
        "gaul_code":"97",
        "iso3_code":"GRC",
        "from_v":4,
        "to_h":20
    },
    {
        "to_v":11,
        "iso2_code":"PY",
        "from_h":12,
        "gaul_label":"Paraguay",
        "gaul_code":"194",
        "iso3_code":"PRY",
        "from_v":10,
        "to_h":13
    },
    {
        "to_v":9,
        "iso2_code":"GA",
        "from_h":18,
        "gaul_label":"Gabon",
        "gaul_code":"89",
        "iso3_code":"GAB",
        "from_v":8,
        "to_h":19
    },
    {
        "to_v":20,
        "iso2_code":"93",
        "from_h":488,
        "gaul_label":"\"Moldova",
        "gaul_code":"165",
        "iso3_code":"MD",
        "from_v":19,
        "to_h":489
    },
    {
        "to_v":7,
        "iso2_code":None,
        "from_h":11,
        "gaul_label":"Bird Island",
        "gaul_code":"32",
        "iso3_code":None,
        "from_v":7,
        "to_h":11
    },
    {
        "to_v":10,
        "iso2_code":"KM",
        "from_h":22,
        "gaul_label":"Comoros",
        "gaul_code":"58",
        "iso3_code":"COM",
        "from_v":10,
        "to_h":22
    }
]